@@ -96,7 +96,7 @@ def sign(values, secret_salt, keys = None, length_used = None):
 
     return the_hash
 
-def verify(values, secret_salt, hash, 
+def verify(values, secret_salt, ahash, 
            keys = None, 
            length_used = None,
            random_sleep = True,
@@ -107,7 +107,7 @@ def verify(values, secret_salt, hash,
 
         values:      list of the value parts of '&key=value'
         secret_salt: secret string to secret_salt the hash.
-        hash:        the hash to check with.
+        ahash:        the hash to check with.
         keys:        list of the key parts of '&key=value'
         length_used: if None use the full length of the hash.  If an 
                        integer, then use that length of the hash.
@@ -132,10 +132,14 @@ def verify(values, secret_salt, hash,
         time.sleep(random.randint(50,100) * 0.00001)
 
     #note, we must make sure they are both the same length.
-    if len(the_hash) is not len(hash):
+    #print 'len(the_hash) is not len(ahash)'
+    #print len(the_hash) is not len(ahash)
+    #print len(the_hash), len(ahash)
+
+    if len(the_hash) != len(ahash):
         return False
     result = 0
-    for a,b in zip(the_hash, hash):
+    for a,b in zip(the_hash, ahash):
         result |= ord(a) ^ ord(a)
 
     return result == 0
